%% PTrussDataInput.m
%  Reads model data from input file
%  This file is part of the PTrussMatlab program


%% Ask for input file name, open it and start reading
InputFileName = input('Give input file name : ','s'); %Ask for input file name
fileID = fopen(InputFileName,'r'); %Open input file

tline = fgetl(fileID); %Read a useless row (*PTrussMatlab input file)
tline = fgetl(fileID); %Read a useless row (blank)

%% Read material data
% E: Material modulus of Elasticity
tline = fgetl(fileID); %Read a useless row (*Materials)

NumMaterials=fscanf(fileID, '%i', [1 1]); %Read number of materials
MaterialProperties=zeros(NumMaterials,1); %Initialize MaterialProperties vector

a=fscanf(fileID, '%i %g', [2 NumMaterials]); %Read IDs, E matrix
a=a';
MaterialProperties(:)=a(:,2); %Assign E to MaterialProperties
tline = fgetl(fileID); %Move to next line


%% Read section data
% A: Cross section area
tline = fgetl(fileID); %Read a useless row (blank)
tline = fgetl(fileID); %Read a useless row (*Sections)

NumSections=fscanf(fileID, '%i' , [1 1]); %Read number of sections
SectionProperties=zeros(NumSections,1); %Initialize SectionProperties matrix

a=fscanf(fileID, '%i %g', [2 NumSections]); %Read IDs, A
a=a';
SectionProperties(:)=a(:,2); %Assign A to SectionProperties
tline = fgetl(fileID); %Move to next line


%% Read nodal data
% x coordinate
% y coordinate
tline = fgetl(fileID); %Read a useless row (blank)
tline = fgetl(fileID); %Read a useless row (*Nodes)

NumNodes=fscanf(fileID, '%i' , [1 1]); %Read number of nodes
NodesCoordinates=zeros(NumNodes,2); %Initialize NodesCoordinates matrix

a=fscanf(fileID, '%i %g %g', [3 NumNodes]); %Read IDs, x, y
a=a';
NodesCoordinates(:)=a(:,2:3); %Assign x, y to NodesCoordinates
tline = fgetl(fileID); %Move to next line


%% Read elemental data (x, y coordinates)
% Start Node i
% End Node j
% Material Group
% Section Group

tline = fgetl(fileID); %Read a useless row (blank)
tline = fgetl(fileID); %Read a useless row (*Elements)

NumElements=fscanf(fileID, '%i' , [1 1]); %Read number of elements
ElementProperties=zeros(NumElements,4); %Initialize ElementProperties matrix

a=fscanf(fileID, '%i %i %i %i %i', [5 NumElements]); %Read IDs, Node_i, Node_j, Mat_Group, Sec_Group
a=a';
ElementProperties(:)=a(:,2:5); %Assign Node_i, Node_j, Mat_Group, Sec_Group to ElementProperties
tline = fgetl(fileID); %Move to next line


%% Read constraints
% x constraint
% y constraint

tline = fgetl(fileID); %Read a useless row (blank)
tline = fgetl(fileID); %Read a useless row (*Constraints)

NumConstraints=fscanf(fileID, '%i' , [1 1]); %Read number of constrained nodes
BoundaryConditions=zeros(NumNodes,2); %Initialize BoundaryConditions matrix

if NumConstraints==0; %If no constraints exist, read nothing
else
	for n=1:NumConstraints
        a=fscanf(fileID, '%i %i %i', [1 3]); %Read ID, x_constr, y_constr
        node_constr=a(1); %Read ID of constrained node
		BoundaryConditions(node_constr,1:2)=a(2:3); %Assign x_constr, y_constr to the constrained node
	end
end

tline = fgetl(fileID); %Move to next line


%% Read nodal loads
% x load (force) - global system
% y load (force) - global system

tline = fgetl(fileID); %Read a useless row (blank)
tline = fgetl(fileID); %Read a useless row (*Nodal_Loads)

NumNodalLoads=fscanf(fileID, '%i' , [1 1]); %Read number of Nodes with loads on
NodalLoads=zeros(NumNodes,2); %Initialize NodalLoads matrix

if NumNodalLoads==0; %If no nodal loads exist, read nothing
else
	for n=1:NumNodalLoads
        a=fscanf(fileID, '%i %g %g', [1 3]); %Read ID, x_load, y_load
        node_loaded=a(1); %Read ID of loaded node
		NodalLoads(node_loaded,1:2)=a(2:3); %Assign x_load, y_load to the loaded node
	end
end


%% Close input file
fclose(fileID);

% End of file -------------------------------------------------------------